@@ -34,12 +34,14 @@ from majormode.perseus.model.contact import Contact
 from majormode.perseus.model.locale import DEFAULT_LOCALE
 from majormode.perseus.model.locale import Locale
 from majormode.perseus.model.obj import Object
+from majormode.perseus.utils import module_util
 from majormode.perseus.utils.date_util import ISO8601DateTime
 from majormode.perseus.utils.rdbms import RdbmsConnection
 
 from majormode.perseus.service.base_rdbms_service import BaseRdbmsService
 from majormode.perseus.service.base_service import BaseService
-from majormode.perseus.utils import cast, rdbms
+from majormode.perseus.utils import cast
+from majormode.perseus.utils import rdbms
 
 
 class ContactService(BaseRdbmsService):
@@ -424,7 +426,7 @@ class ContactService(BaseRdbmsService):
             logging.error(f"The account {account_id} is not associated with the contact {old_contact.property_value}")
             raise self.IllegalAccessException(f"The user is not associated with the specified contact")
 
-        if not self.is_contact_available(new_contact, connection=connection)
+        if not self.is_contact_available(new_contact, connection=connection):
             logging.error(f"The contact {new_contact.property_value} is already in use")
             raise self.InvalidOperationException("The new requested contact is already in use")
 
@@ -433,7 +435,7 @@ class ContactService(BaseRdbmsService):
             self.VERIFICATION_CODE_MAXIMUM_DIGIT_COUNT
         ))
 
-        expiration_time =
+        expiration_time = None
 
         cursor = connection.execute(
             """
@@ -817,8 +819,6 @@ class ContactService(BaseRdbmsService):
         :raise InvalidArgumentException: if this contact information is stated
             as verified while no challenge process has been passed.
         """
-        from majormode.perseus.service.account.account_service import AccountService
-
         assert not (has_been_verified and to_be_verified), "Conflicted values"
 
         # Check whether this contact has been already added to this account.
@@ -1326,3 +1326,6 @@ class ContactService(BaseRdbmsService):
                     'property_name': contact.property_name,
                     'property_value': contact.property_value,
                 })
+
+
+AccountService = module_util.load_class('majormode.perseus.service.account.account_service.AccountService')
