@@ -15,15 +15,5 @@
  * OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */
 
-ALTER TABLE account_picture
-  ADD COLUMN is_review_required boolean NOT DEFAULT false;
-
-DROP TRIGGER on_account_picture_updated;
-
-DROP FUNCTION on_account_picture_updated();
-
 ALTER TABLE account
-  DROP COLUMN image_width,
-  DROP COLUMN image_height,
-  DROP COLUMN image_file_size,
-  DROP COLUMN image_file_checksum;
\ No newline at end of file
+  ADD COLUMN last_login_time timestamptz(3) NULL;
